@@ -85,7 +85,7 @@ def writeTar(repo,oldhash,args):
         newesthash=newesthashlist[0]
     except IndexError: pass
 
-    reposubdir=os.path.basename(repo.path)
+    reposubdir=repo.path
     if args.tarfile=='-':
         tar=tarfile.open(fileobj=sys.stdout,mode='w|')
     else:
@@ -113,7 +113,7 @@ def writeTar(repo,oldhash,args):
     tar.close()
     return newesthash
 
-
+# print full path of repo file
 def printFiles(repo,oldhash,args):
     journal=Benno.Journal()
     for box in Benno.Box.GetBoxes(repo.boxstate):
